FmtCompact

Trait FmtCompact 

pub trait FmtCompact<'a> {
    type Report: Display + 'a;

    // Required method
    fn fmt_compact(self) -> Self::Report;
}
Simple utility trait to print error chains

Implemented for a reference to any error, dyn Error included, so method calls also reach the error behind a Box<dyn Error> or any other pointer that derefs to one.

Required Associated Types

Required Methods

fn fmt_compact(self) -> Self::Report

Implementations on Foreign Types

Source

impl<'e, E> FmtCompact<'e> for &'e E
where E: Error + ?Sized,

Implementors